==> digikam-4.3.0.tar.bz2: digikam-4.3.0/extra/kipi-plugins/facebook/kipiplugin_facebook.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Facebook Import/Export
Name=Facebook Import/Export
Name[ast]=Esportador/Importador Facebook
Name[bg]=Внасяне и изнасяне от Facebook
Name[bs]=Facebook uvoz/izvoz
Name[ca]=Importador/Exportador a Facebook
Name[ca@valencia]=Importador/Exportador a Facebook
Name[cs]=Facebook Import/Export
Name[da]=Facebook import/eksport
Name[de]=Facebook-Import/Export
Name[el]=Εισαγωγέας/εξαγωγέας Facebook
Name[en_GB]=Facebook Import/Export
Name[es]=Importar/Exportar a Facebook
Name[et]=Facebooki import/eksport
Name[eu]=Facebook-en inportazioa/esportazioa
Name[fi]=Facebook tuonti/vienti
Name[fr]=Importation / Exportation Facebook
Name[ga]=Iompórtáil/Easpórtáil Facebook
Name[gl]=Importación/Exportación a Facebook
Name[hu]=Facebook importálás/exportálás
Name[is]=Facebook inn/útflutningur
Name[it]=Importazione ed esportazione a Facebook
Name[ja]=Facebook Import/Export
Name[km]=នាំចេញ/នាំចូល Facebook
Name[lt]=Facebook Importas/Eksportas
Name[lv]=Importēt no/Eksportēt uz Facebook
Name[nb]=Facebook-import/eksport
Name[nds]=Facebook im- un exporteren
Name[nl]=Facebook-import/export
Name[pa]=ਫੇਸਬੁੱਕ ਇੰਪੋਰਟਰ/ਐਕਸਪੋਟਰ
Name[pl]=Import/Eksport z Facebooka
Name[pt]=Importação/Exportação para o Facebook
Name[pt_BR]=Importar/exportar para o Facebook
Name[ro]=Import/Export Facebook
Name[ru]=Импорт и экспорт в Facebook
Name[sk]=Facebook import/export
Name[sl]=Uvoz/izvoz za Facebook
Name[sq]=Facebook Importo/Eksporto
Name[sv]=Facebook import och export
Name[th]=นำเข้า/ส่งออก ไปยังบริการ Facebook
Name[tr]=Facebook İçeriye/Dışarıya Aktar
Name[uk]=Імпорт/Експорт до Facebook
Name[x-test]=xxFacebook Import/Exportxx
Name[zh_CN]=Facebook 导入/导出
Name[zh_TW]=Facebook 匯入/匯出
Comment=A tool to import/export images to/from a remote Facebook web service
Comment[ast]=Una ferramienta pa importar/esportar imáxenes pa/dende'l serviciu web remotu de Facebook
Comment[bg]=Инструмент за внасяне и изнасяне на изображения към и от отдалечена уеб-услуга Facebook
Comment[bs]=Alat za uvoz/izvoz slika u/iz udaljeni/udaljenog Facebook web servis
Comment[ca]=Una eina per importar/exportar imatges a un servei web remot Facebook
Comment[ca@valencia]=Una eina per importar/exportar imatges a un servei web remot Facebook
Comment[cs]=Nástroj pro import/export obrázků z/do vzdálené webové služby Facebook
Comment[da]=Et værktøj til at importere/eksportere billeder fra/til en ekstern Facebook-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zum/vom Facebook-Webdienst im- bzw. exportieren.
Comment[el]=Εργαλείο για την εισαγωγή/εξαγωγή εικόνων από/σε μια απομακρυσμένη υπηρεσία ιστού Facebook
Comment[en_GB]=A tool to import/export images to/from a remote Facebook web service
Comment[es]=Una herramienta para importar/exportar imágenes al servicio web remoto de Facebook
Comment[et]=Tööriist piltide importimiseks/eksportimiseks Facebooki veebiteenusest/veebiteenusesse
Comment[eu]=Urruneko Facebook web zerbitzutik irudiak inportatzeko/esportatzeko tresna
Comment[fr]=Outil pour l'importation / exportation d'images depuis / vers le service en ligne Facebook
Comment[gl]=Unha ferramenta para importar ou exportar imaxes a un servizo web Facebook remoto
Comment[hu]=Egy eszköz képek importálásához/exportálásához egy távoli Facebook webszolgáltatáshoz
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlægum Facebook vefþjónustum
Comment[it]=Uno strumento per importare ed esportare immagini da e al servizio Web remoto Facebook
Comment[ja]=画像を Facebook ウェブサービスにエクスポート/からインポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ/នាំចូល​​រូបភាព​ទៅ/ពីសេវា​បណ្ដាញ​របស់ Facebook ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu importēšanai no/eksportēšanai uz attālināto Facebook tīmekļa servisu
Comment[nb]=Et verktøy for å importere/eksportere bilder til/fra en fjern Facebook-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na/vun en feern Facebook-Nettdeenst im- un exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen van/naar een Facebook-webservice te im/exporteren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਰਿਮੋਟ ਫੇਸਬੁੱਕ ਵੈੱਬ ਸਰਵਿਸ ਵੱਲ/ਵਲੋਂ ਲੈਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do importowania/eksportowania obrazów z/do zdalnej usługi sieciowej Facebooka
Comment[pt]=Uma ferramenta para importar/exportar imagens para o serviço Web remoto do Facebook
Comment[pt_BR]=Uma ferramenta para importar/exportar imagens para um serviço da Internet remoto Facebook
Comment[ro]=O unealtă de importat/exportat imagini din/pe serviciul web Facebook
Comment[ru]=Инструмент для импорта и экспорта в социальную сеть Facebook
Comment[sk]=Nástroj na import a export obrzákov do a z Facebook-u
Comment[sl]=Orodje za uvoz/izvoz slik v/iz oddaljene spletne storitve Facebook
Comment[sq]=Një mjet për të importuar/eksportuar imazhet nga/tek shërbimi i internetit Facebook
Comment[sv]=Ett verktyg för att importera bilder från eller exportera bilder till en Facebook fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Facebook ทางไกล
Comment[tr]=Resimleri uzak bir Facebook web hizmetine aktarmak ve oradan almak için bir araç
Comment[uk]=Інструмент для імпорту/експорту зображень до/з віддаленої служби Facebook
Comment[x-test]=xxA tool to import/export images to/from a remote Facebook web servicexx
Comment[zh_CN]=一个将图像从远程 Facebook 网络服务导入/导出到远程 Facebook 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Facebook 網頁服務/從遠端 Facebook 網頁服務匯入影像的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_facebook
Icon=kipi-facebook
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Luka Renko, lure at kubuntu dot org

==> digikam-4.7.0.tar.bz2: digikam-4.7.0/extra/kipi-plugins/facebook/kipiplugin_facebook.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Facebook Import/Export
Name=Facebook Import/Export
Name[ast]=Esportador/Importador Facebook
Name[bg]=Внасяне и изнасяне от Facebook
Name[bs]=Facebook uvoz/izvoz
Name[ca]=Importador/Exportador a Facebook
Name[ca@valencia]=Importador/Exportador a Facebook
Name[cs]=Facebook Import/Export
Name[da]=Facebook import/eksport
Name[de]=Facebook-Import/Export
Name[el]=Εισαγωγέας/εξαγωγέας Facebook
Name[en_GB]=Facebook Import/Export
Name[es]=Importar/Exportar a Facebook
Name[et]=Facebooki import/eksport
Name[eu]=Facebook-en inportazioa/esportazioa
Name[fi]=Facebook-tuonti/vienti
Name[fr]=Importation / Exportation Facebook
Name[ga]=Iompórtáil/Easpórtáil Facebook
Name[gl]=Importación/Exportación a Facebook
Name[hu]=Facebook importálás/exportálás
Name[is]=Facebook inn/útflutningur
Name[it]=Importazione ed esportazione a Facebook
Name[ja]=Facebook Import/Export
Name[km]=នាំចេញ/នាំចូល Facebook
Name[lt]=Facebook Importas/Eksportas
Name[lv]=Importēt no/Eksportēt uz Facebook
Name[nb]=Facebook-import/eksport
Name[nds]=Facebook im- un exporteren
Name[nl]=Facebook-import/export
Name[pa]=ਫੇਸਬੁੱਕ ਇੰਪੋਰਟਰ/ਐਕਸਪੋਟਰ
Name[pl]=Import/Eksport z Facebooka
Name[pt]=Importação/Exportação para o Facebook
Name[pt_BR]=Importar/exportar para o Facebook
Name[ro]=Import/Export Facebook
Name[ru]=Импорт и экспорт в Facebook
Name[sk]=Facebook import/export
Name[sl]=Uvoz/izvoz za Facebook
Name[sq]=Facebook Importo/Eksporto
Name[sv]=Facebook import och export
Name[th]=นำเข้า/ส่งออก ไปยังบริการ Facebook
Name[tr]=Facebook İçeriye/Dışarıya Aktar
Name[uk]=Імпорт/Експорт до Facebook
Name[x-test]=xxFacebook Import/Exportxx
Name[zh_CN]=Facebook 导入/导出
Name[zh_TW]=Facebook 匯入/匯出
Comment=A tool to import/export images to/from a remote Facebook web service
Comment[ast]=Una ferramienta pa importar/esportar imáxenes pa/dende'l serviciu web remotu de Facebook
Comment[bg]=Инструмент за внасяне и изнасяне на изображения към и от отдалечена уеб-услуга Facebook
Comment[bs]=Alat za uvoz/izvoz slika u/iz udaljeni/udaljenog Facebook web servis
Comment[ca]=Una eina per importar/exportar imatges a un servei web remot Facebook
Comment[ca@valencia]=Una eina per importar/exportar imatges a un servei web remot Facebook
Comment[cs]=Nástroj pro import/export obrázků z/do vzdálené webové služby Facebook
Comment[da]=Et værktøj til at importere/eksportere billeder fra/til en ekstern Facebook-webtjeneste
Comment[de]=Ein Werkzeug, um Bilder zum/vom Facebook-Webdienst im- bzw. exportieren.
Comment[el]=Εργαλείο για την εισαγωγή/εξαγωγή εικόνων από/σε μια απομακρυσμένη υπηρεσία ιστού Facebook
Comment[en_GB]=A tool to import/export images to/from a remote Facebook web service
Comment[es]=Una herramienta para importar/exportar imágenes al servicio web remoto de Facebook
Comment[et]=Tööriist piltide importimiseks/eksportimiseks Facebooki veebiteenusest/veebiteenusesse
Comment[eu]=Urruneko Facebook web zerbitzutik irudiak inportatzeko/esportatzeko tresna
Comment[fi]=Kuvien tuonti Facebookista ja vienti Facebookiin
Comment[fr]=Outil pour l'importation / exportation d'images depuis / vers le service en ligne Facebook
Comment[gl]=Unha ferramenta para importar ou exportar imaxes a un servizo web Facebook remoto
Comment[hu]=Egy eszköz képek importálásához/exportálásához egy távoli Facebook webszolgáltatáshoz
Comment[is]=Verkfæri til að senda/flytja inn myndir frá fjarlægum Facebook vefþjónustum
Comment[it]=Uno strumento per importare ed esportare immagini da e al servizio Web remoto Facebook
Comment[ja]=画像を Facebook ウェブサービスにエクスポート/からインポートするツール
Comment[km]=ឧបករណ៍​ត្រូវ​នាំចេញ/នាំចូល​​រូបភាព​ទៅ/ពីសេវា​បណ្ដាញ​របស់ Facebook ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu importēšanai no/eksportēšanai uz attālināto Facebook tīmekļa servisu
Comment[nb]=Et verktøy for å importere/eksportere bilder til/fra en fjern Facebook-nettjeneste
Comment[nds]=En Warktüüch, mit dat sik Biller na/vun en feern Facebook-Nettdeenst im- un exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen van/naar een Facebook-webservice te im/exporteren
Comment[pa]=ਚਿੱਤਰਾਂ ਨੂੰ ਰਿਮੋਟ ਫੇਸਬੁੱਕ ਵੈੱਬ ਸਰਵਿਸ ਵੱਲ/ਵਲੋਂ ਲੈਣ ਲਈ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do importowania/eksportowania obrazów z/do zdalnej usługi sieciowej Facebooka
Comment[pt]=Uma ferramenta para importar/exportar imagens para o serviço Web remoto do Facebook
Comment[pt_BR]=Ferramenta para importar/exportar imagens para o Facebook
Comment[ro]=O unealtă de importat/exportat imagini din/pe serviciul web Facebook
Comment[ru]=Инструмент для импорта и экспорта в социальную сеть Facebook
Comment[sk]=Nástroj na import a export obrzákov do a z Facebook-u
Comment[sl]=Orodje za uvoz/izvoz slik v/iz oddaljene spletne storitve Facebook
Comment[sq]=Një mjet për të importuar/eksportuar imazhet nga/tek shërbimi i internetit Facebook
Comment[sv]=Ett verktyg för att importera bilder från eller exportera bilder till en Facebook fjärrwebbtjänst
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังเว็บบริการ Facebook ทางไกล
Comment[tr]=Resimleri uzak bir Facebook web hizmetine aktarmak ve oradan almak için bir araç
Comment[uk]=Інструмент для імпорту/експорту зображень до/з віддаленої служби Facebook
Comment[x-test]=xxA tool to import/export images to/from a remote Facebook web servicexx
Comment[zh_CN]=一个将图像从远程 Facebook 网络服务导入/导出到远程 Facebook 网络服务的工具
Comment[zh_TW]=匯出影像到遠端 Facebook 網頁服務/從遠端 Facebook 網頁服務匯入影像的工具
Type=Service
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_facebook
Icon=kipi-facebook
X-KIPI-PluginCategories=Export,Import
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Luka Renko, lure at kubuntu dot org
